ServiceInstallCtx

Struct ServiceInstallCtx 

pub struct ServiceInstallCtx {
    pub label: ServiceLabel,
    pub program: PathBuf,
    pub args: Vec<OsString>,
    pub contents: Option<String>,
    pub username: Option<String>,
    pub working_directory: Option<PathBuf>,
    pub environment: Option<Vec<(String, String)>>,
    pub autostart: bool,
    pub restart_policy: RestartPolicy,
}
Context provided to the install function of ServiceManager

Fields

label: ServiceLabel

Label associated with the service

E.g. org.example.my_application

program: PathBuf

Path to the program to run

E.g. /usr/local/bin/my-program

args: Vec<OsString>

Arguments to use for the program

E.g. --arg, value, --another-arg

contents: Option<String>

Optional contents of the service file for a given ServiceManager to use instead of the default template.

username: Option<String>

Optionally supply the user the service will run as

If not specified, the service will run as the root or Administrator user.

working_directory: Option<PathBuf>

Optionally specify a working directory for the process launched by the service

environment: Option<Vec<(String, String)>>

Optionally specify a list of environment variables to be passed to the process launched by the service

autostart: bool

Specify whether the service should automatically start on reboot

restart_policy: RestartPolicy

Specify the restart policy for the service

This controls when and how the service should be restarted if it exits. Different platforms support different levels of granularity - see RestartPolicy documentation for details.

Defaults to RestartPolicy::OnFailure if not specified.

Implementations

Source

impl ServiceInstallCtx

pub fn cmd_iter(&self) -> impl Iterator<Item = &OsStr>

Iterator over the program and its arguments

pub fn args_iter(&self) -> impl Iterator<Item = &OsStr>

Iterator over the program arguments